@@ -151,6 +151,11 @@ class ElasticSolid(RigidSolid):
 
     @nu_s.setter
     def nu_s(self, value: float) -> None:
+        if not (0 <= value <= 0.5):
+            raise ValueError(
+                'The Poisson\'s ratio `nu` needs to be in the '
+                'range 0 <= nu <= 0.5',
+            )
         self._nu_s.value = value
 
     # -------------------------------------------------------------------------
