@@ -209,7 +209,9 @@ class ARFPlot:
                 display_values, data, ax, plot_method, **kwargs,
             )
 
-        self.plotter.set_labels(ax, self.attr_name, normalization)
+        is_normalized = False if normalization is None else True
+
+        self.plotter.set_labels(ax, self.attr_name, is_normalized)
         self.plotter.add_legend(ax)
 
         return fig, ax
