@@ -1,5 +1,4 @@
-from collections.abc import Sequence
-from typing import Union
+from typing import Sequence, Union
 
 import numpy as np
 
@@ -21,6 +20,7 @@ class Grid:
     :param theta_max: end point for tangential plotting range in [rad]
     :param res: resolution, if tuple (radial resolution, tangential resolution)
     """
+
     def __init__(
         self,
         r_min: float,
