@@ -87,23 +87,21 @@ class TriangulationPlotter(BaseScatteringPlotter):
         if symmetric:
             C = np.concatenate([C, C])
 
-        cmap = self.div_cmap if use_diverging_cmap else self.cmap
+        if 'cmap' not in kwargs.keys():
+            cmap = self.div_cmap if use_diverging_cmap else self.cmap
+            kwargs['cmap'] = cmap
 
         # Plot tripcolor or tricontourf plot
         if tripcolor:
-            trc = ax.tripcolor(
-                triang, C, cmap=cmap, shading='gouraud', **kwargs
-            )
+            if 'shading' not in kwargs.keys():
+                kwargs['shading'] = 'gouraud'
+
+            trc = ax.tripcolor(triang, C, **kwargs)
         else:
-            trc = ax.tricontourf(
-                triang, C, cmap=cmap, **kwargs
-            )
+            trc = ax.tricontourf(triang, C, **kwargs)
 
         # Add color bar, axis limits, axis labels, etc.
-        cbar = self._finish_triplot(
-            fig, ax, radius, trc,
-            cbar_label,
-        )
+        cbar = self._finish_triplot(fig, ax, radius, trc, cbar_label)
 
         return fig, ax, trc, cbar, triang
 
