@@ -4,7 +4,7 @@ import numpy as np
 
 from osaft.core.backgroundfields import WaveType
 from osaft.core.frequency import Frequency
-from osaft.core.functions import SpecialFunctions as Sp
+from osaft.core.functions import BesselFunctions as Bf
 from osaft.core.geometries import Sphere
 from osaft.core.variable import ActiveListVariable, ActiveVariable
 from osaft.solutions.doinikov1994compressible.base import (
@@ -16,18 +16,18 @@ class CoefficientMatrix(BaseDoinikov1994Compressible):
     """Coefficient Matrix Doinikov (viscous fluid-viscous sphere; 1994)
 
     :param f: Frequency [Hz]
-    :param R_0: Radius of the solid [m]
-    :param rho_s: Density of the fluid-like solid [kg/m^3]
-    :param c_s: Speed of sound of the sphere [m/s]
-    :param eta_s: shear viscosity of the sphere [Pa s]
-    :param zeta_s: bulk viscosity of the sphere [Pa s]
+    :param R_0: Radius of the sphere [m]
+    :param rho_s: Density of the sphere [kg/m^3]
+    :param c_s: Speed of sound of in the sphere [m/s]
+    :param eta_s: shear viscosity of in the sphere  [Pa s]
+    :param zeta_s: bulk viscosity of in the sphere [Pa s]
     :param rho_f: Density of the fluid [kg/m^3]
     :param c_f: Speed of sound of the fluid [m/s]
     :param eta_f: shear viscosity [Pa s]
     :param zeta_f: bulk viscosity [Pa s]
     :param p_0: Pressure amplitude of the field [Pa]
     :param position: Position within the standing wave field [m]
-    :param wave_type: Type of wave, travel(l)ing or standing
+    :param wave_type: Type of wave, traveling or standing
     """
 
     def __init__(
@@ -133,17 +133,17 @@ class CoefficientMatrix(BaseDoinikov1994Compressible):
     def _compute_vector_N_n(self, n: int) -> np.ndarray:
         vector = np.zeros(4, dtype=complex)
 
-        vector[0] = -self.x * Sp.d1_besselj(n, self.x)
+        vector[0] = -self.x * Bf.d1_besselj(n, self.x)
 
-        vector[1] = -Sp.besselj(n, self.x)
+        vector[1] = -Bf.besselj(n, self.x)
         vector[2] = 1j * self.rho_f * self.c_f**2 / self.omega
         vector[2] += self.zeta_f
         vector[2] -= 2 / 3 * self.eta_f
-        vector[2] *= Sp.besselj(n, self.x)
-        vector[2] -= 2 * self.eta_f * Sp.d2_besselj(n, self.x)
+        vector[2] *= Bf.besselj(n, self.x)
+        vector[2] -= 2 * self.eta_f * Bf.d2_besselj(n, self.x)
         vector[2] *= self.x**2
-        vector[3] = Sp.besselj(n, self.x)
-        vector[3] -= self.x * Sp.d1_besselj(n, self.x)
+        vector[3] = Bf.besselj(n, self.x)
+        vector[3] -= self.x * Bf.d1_besselj(n, self.x)
         vector[3] *= 2 * self.eta_f
 
         return vector
@@ -158,55 +158,55 @@ class CoefficientMatrix(BaseDoinikov1994Compressible):
         matrix = np.zeros((4, 4), dtype=complex)
 
         # First row
-        matrix[0, 0] = self.x * Sp.d1_hankelh1(n, self.x)
-        matrix[0, 1] = -n * (n + 1) * Sp.hankelh1(n, self.x_v)
-        matrix[0, 2] = - self.x_hat * Sp.d1_besselj(n, self.x_hat)
-        matrix[0, 3] = n * (n + 1) * Sp.besselj(n, self.x_hat_v)
+        matrix[0, 0] = self.x * Bf.d1_hankelh1(n, self.x)
+        matrix[0, 1] = -n * (n + 1) * Bf.hankelh1(n, self.x_v)
+        matrix[0, 2] = - self.x_hat * Bf.d1_besselj(n, self.x_hat)
+        matrix[0, 3] = n * (n + 1) * Bf.besselj(n, self.x_hat_v)
 
         # Second Row
-        matrix[1, 0] = Sp.hankelh1(n, self.x)
-        matrix[1, 1] = -Sp.hankelh1(n, self.x_v)
-        matrix[1, 1] -= self.x_v * Sp.d1_hankelh1(n, self.x_v)
-        matrix[1, 2] = -Sp.besselj(n, self.x_hat)
-        matrix[1, 3] = Sp.besselj(n, self.x_hat_v)
-        matrix[1, 3] += self.x_hat_v * Sp.d1_besselj(n, self.x_hat_v)
+        matrix[1, 0] = Bf.hankelh1(n, self.x)
+        matrix[1, 1] = -Bf.hankelh1(n, self.x_v)
+        matrix[1, 1] -= self.x_v * Bf.d1_hankelh1(n, self.x_v)
+        matrix[1, 2] = -Bf.besselj(n, self.x_hat)
+        matrix[1, 3] = Bf.besselj(n, self.x_hat_v)
+        matrix[1, 3] += self.x_hat_v * Bf.d1_besselj(n, self.x_hat_v)
 
         # Third row
         matrix[2, 0] = 1j * self.rho_f * self.c_f**2 / self.omega
         matrix[2, 0] += self.zeta_f
         matrix[2, 0] -= 2 / 3 * self.eta_f
-        matrix[2, 0] *= -Sp.hankelh1(n, self.x)
-        matrix[2, 0] += 2 * self.eta_f * Sp.d2_hankelh1(n, self.x)
+        matrix[2, 0] *= -Bf.hankelh1(n, self.x)
+        matrix[2, 0] += 2 * self.eta_f * Bf.d2_hankelh1(n, self.x)
         matrix[2, 0] *= self.x**2
 
-        matrix[2, 1] = Sp.hankelh1(n, self.x_v)
-        matrix[2, 1] -= self.x_v * Sp.d1_hankelh1(n, self.x_v)
+        matrix[2, 1] = Bf.hankelh1(n, self.x_v)
+        matrix[2, 1] -= self.x_v * Bf.d1_hankelh1(n, self.x_v)
         matrix[2, 1] *= 2 * n * (n + 1) * self.eta_f
 
         matrix[2, 2] = 1j * self.rho_s * self.c_s**2 / self.omega
         matrix[2, 2] += self.zeta_s
         matrix[2, 2] -= 2 / 3 * self.eta_s
-        matrix[2, 2] *= Sp.besselj(n, self.x_hat)
-        matrix[2, 2] -= 2 * self.eta_s * Sp.d2_besselj(n, self.x_hat)
+        matrix[2, 2] *= Bf.besselj(n, self.x_hat)
+        matrix[2, 2] -= 2 * self.eta_s * Bf.d2_besselj(n, self.x_hat)
         matrix[2, 2] *= self.x_hat**2
 
-        matrix[2, 3] = self.x_hat_v * Sp.d1_besselj(n, self.x_hat_v)
-        matrix[2, 3] -= Sp.besselj(n, self.x_hat_v)
+        matrix[2, 3] = self.x_hat_v * Bf.d1_besselj(n, self.x_hat_v)
+        matrix[2, 3] -= Bf.besselj(n, self.x_hat_v)
         matrix[2, 3] *= 2 * n * (n + 1) * self.eta_s
 
         # Fourth row
-        matrix[3, 0] = self.x * Sp.d1_hankelh1(n, self.x)
-        matrix[3, 0] -= Sp.hankelh1(n, self.x)
+        matrix[3, 0] = self.x * Bf.d1_hankelh1(n, self.x)
+        matrix[3, 0] -= Bf.hankelh1(n, self.x)
         matrix[3, 0] *= 2 * self.eta_f
-        matrix[3, 1] = self.x_v**2 * Sp.d2_hankelh1(n, self.x_v)
-        matrix[3, 1] += (n**2 + n - 2) * Sp.hankelh1(n, self.x_v)
+        matrix[3, 1] = self.x_v ** 2 * Bf.d2_hankelh1(n, self.x_v)
+        matrix[3, 1] += (n**2 + n - 2) * Bf.hankelh1(n, self.x_v)
         matrix[3, 1] *= -self.eta_f
-        matrix[3, 2] = Sp.besselj(n, self.x_hat)
-        matrix[3, 2] -= self.x_hat * Sp.d1_besselj(n, self.x_hat)
+        matrix[3, 2] = Bf.besselj(n, self.x_hat)
+        matrix[3, 2] -= self.x_hat * Bf.d1_besselj(n, self.x_hat)
         matrix[3, 2] *= 2 * self.eta_s
 
-        matrix[3, 3] = self.x_hat_v**2 * Sp.d2_besselj(n, self.x_hat_v)
-        matrix[3, 3] += (n**2 + n - 2) * Sp.besselj(n, self.x_hat_v)
+        matrix[3, 3] = self.x_hat_v ** 2 * Bf.d2_besselj(n, self.x_hat_v)
+        matrix[3, 3] += (n**2 + n - 2) * Bf.besselj(n, self.x_hat_v)
         matrix[3, 3] *= self.eta_s
         return matrix
 
