@@ -86,6 +86,8 @@ class BaseTestFluidScattering(BaseTestScattering):
             symmetric=False,
             incident=True,
             scattered=True,
+            shading='flat',
+            cmap='jet',
         )
 
         name = inspect.stack()[0][3]  # method name
