@@ -1,7 +1,7 @@
 import unittest
 
 from osaft import gorkov1962, settnes2012
-from osaft.core.backgroundfields import WrongWaveTypeError
+from osaft.core.backgroundfields import WaveType, WrongWaveTypeError
 from osaft.core.functions import pi, sin
 from osaft.tests.basetest import BaseTest
 from osaft.tests.basetest_arf import (
@@ -95,6 +95,9 @@ class TestCompareToGorkov(BaseTest, HelperCompareARF):
 
         self.arf_compare_threshold = 1e-4
         self.eta_f = 0
+        self.test_variables.remove(self._eta_f)
+        self._wave_type.list_of_values = [WaveType.STANDING]
+        self.wave_type = WaveType.STANDING
 
         self.cls = settnes2012.ARF(
             self.f,
